Welcome to SQLSoup’s documentation! — SQLSoup 0.9.0 documentation

### Navigation

- index
- modules |
- next |
- SQLSoup 0.9.0 documentation »

# Welcome to SQLSoup’s documentation!

SQLSoup is a one step database access tool built on top of the SQLAlchemy Object Relational Mapper.

- Front Matter
  - Project Homepage
  - Project Status
  - Installation
  - Community
  - Bugs
- Tutorial
  - Getting Ready to Connect
  - Loading objects
  - Basic Table Usage
  - Modifying objects
  - Joins
  - Relationships
  - Advanced Use
- API Details

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- SQLSoup 0.9.0 documentation »